@@ -21,11 +21,11 @@ class Event:
 events = []
 
 
-def registerEvent(event):
+def register_event(event):
     events.append(event)
 
 
-def unregisterEvent(event):
+def unregister_event(event):
     for e in events:
         if e == event:
             events.remove(e)
@@ -38,4 +38,10 @@ def call(name, *args, scope="global", **kwargs):
                 event.call(*args, **kwargs)
     except Exception as e:
         logger.log(f"§cEvent '{name}' throw exception: {e}")
-        traceback.print_exc()
\ No newline at end of file
+        traceback.print_exc()
+
+
+# --- deprecated --- #
+registerEvent = register_event
+unregisterEvent = unregister_event
+# --- deprecated --- #
