@@ -10,14 +10,16 @@ logPath = ""
 logFile = ""
 timeFormat = "%H:%M:%S"
 
-def initLogDirectory(path):
+
+def init_log(path):
     global logFile, logPath
     logPath = path
     logFile = path + "/" + time.strftime("log_%Y_%m_%d_%H_%M_%S", time.localtime()) + ".txt"
-    tools.createDirectory(path)
+    if not tools.existDirectory(path):
+        tools.createDirectory(path)
     tools.createFile(logFile)
 
-def setTimeFormat(date=False, time=True):
+def set_time_format(date=False, time=True):
     global timeFormat
     if date and time:
         timeFormat = "%Y/%m/%d %H:%M:%S"
@@ -26,25 +28,25 @@ def setTimeFormat(date=False, time=True):
     elif date and not time:
         timeFormat = "%Y/%m/%d"
 
-def getLogByDisplayname(displayname):
+def get_log_by_displayname(displayname):
     return tools.getFileContent(logPath + "/log_" + displayname.replace("/", "_").replace(":", "_").replace(" ", "_") + ".txt")
 
-def getDisplayname(filename):
+def get_displayname(filename):
     pices = filename.replace("log_", "").replace(".txt", "").split("_")
     return pices[0] + "/" + pices[1] + "/" + pices[2] + " " + pices[3] + ":" + pices[4] + ":" + pices[5]
 
-def getAllLogs():
+def get_all_logs():
     list = []
     for filename in os.listdir(logPath):
-        list.append(getDisplayname(filename))
+        list.append(get_displayname(filename))
     return list
 
-def writeToLogFile(message):
-    outLog = "§f" + "[" + time.strftime(timeFormat, time.localtime()) + "] §r" + message
-    try: tools.appendToFile(logFile, outLog)
+def write_to_log_file(message):
+    message = f"§!r§f[{time.strftime(timeFormat, time.localtime())}] §!r{message}§!r"
+    try: tools.appendToFile(logFile, message)
     except: pass
 
-def _replaceColors(message):
+def _replace_colors(message):
     if "§r" in message:
         message = message.replace("§r", Fore.RESET)
     if "§1" in message:
@@ -125,15 +127,27 @@ def log(message):
     logs.append(message)
     try: tools.appendToFile(logFile, message)
     except: pass
-    message = _replaceColors(message)
+    message = _replace_colors(message)
     print(message)
 
-def userInput(message, password=False, strip=True):
+def user_input(message, password=False, strip=True):
     message = f"§!r§f[{time.strftime(timeFormat, time.localtime())}] §!r{message}§!r"
-    message = _replaceColors(message)
+    message = _replace_colors(message)
     if password is True:
         response = str(stdiomask.getpass(prompt=message))
         return response.strip() if strip is True else response
     else:
         print(message, end="")
         return input().strip() if strip is True else input()
+
+
+# --- deprecated --- #
+initLogDirectory = init_log
+setTimeFormat = set_time_format
+getLogByDisplayname = get_log_by_displayname
+getDisplayname = get_displayname
+getAllLogs = get_all_logs
+writeToLogFile = write_to_log_file
+_replaceColors = _replace_colors
+userInput = user_input
+# --- deprecated --- #
\ No newline at end of file
