@@ -1,5 +1,6 @@
 import random, json, os, shutil
 
+
 def getFileContent(path, asBytes=False, asLines=True):
     if asBytes is True:
         with open(path, 'rb') as file:
@@ -20,7 +21,6 @@ def getLineFromFile(path, line):
     content = getFileContent(path)
     if len(content) > line:
         return content[line]
-    return None
 
 def getRandomLineFromFile(path):
     content = getFileContent(path)
@@ -43,8 +43,7 @@ def createFile(path):
     file.close()
 
 def createDirectory(path):
-    try: os.makedirs(path)
-    except:pass
+    os.makedirs(path)
 
 def clearFile(path):
     file = open(path, "w", encoding='utf-8')
@@ -124,4 +123,3 @@ def getRoundRobinValue(list):
             round_robin_indices[id(list)] = 0
         round_robin_indices[id(list)] += 1
         return list[round_robin_indices[id(list)]-1]
-    return None
\ No newline at end of file
