@@ -1,6 +1,7 @@
 import requests, time
 from pythontools.core import logger, tools
 
+
 def uploadToHastebin(content):
     url = 'https://hastebin.com'
     data = ""
@@ -15,20 +16,20 @@ def uploadToHastebin(content):
     response = requests.post(url + '/documents', data=data.encode('utf-8'))
     return url + '/' + response.json()['key']
 
+
 logTimes = {}
 
+
 def startLogTime(name):
     logTimes[name] = time.time()
 
+
 def endLogTime(name, log=True):
     if name in logTimes:
-        convertedTime = convertTime(time.time() - logTimes[name], millis=True)
+        convertedTime = tools.convertTime(time.time() - logTimes[name], millis=True)
         if log:
-            logger.log("§8[§bTIME§8] §e" + str(name) + " finished in §6" + convertedTime)
+            logger.log(f"§8[§bTIME§8] §e{name} finished in §6{convertedTime}")
         logTimes.pop(name)
         return convertedTime
     else:
-        logger.log("§cError: " + str(name) + " not exist!")
-
-convertTime = tools.convertTime  # will be removed in future
-getRoundRobinValue = tools.getRoundRobinValue  # will be removed in future
\ No newline at end of file
+        logger.log(f"§cError: {name} not exist!")
